@@ -8,6 +8,7 @@
 #define WAV_MP2 	80
 #define WAV_WMA 	353
 #define WAV_WMAPRO 	354
+#define WAV_WMALOSSLESS 0x163
 #define WAV_PCM 	1
 #define WAV_MSADPCM 	2
 #define WAV_LPCM 	3
@@ -24,6 +25,7 @@
 #define WAV_8BITS_UNSIGNED 	55 // dummy id
 #define WAV_AMRNB 	56 // dummy id
 #define WAV_AMRWB 	57 // dummy id
+#define WAV_ALAW        6
 #define WAV_ULAW	7 
 #define WAV_QDM2 	58
 #define WAV_IMAADPCM    17
@@ -31,6 +33,7 @@
 #define WAV_NELLYMOSER   9901
 #define WAV_UNKNOWN     9999
 #define WAV_FLAC        61868 // dummy ID
+#define WAV_TRUEHD      0x5254 // 0x44485254
 
 #endif
 //EOF
